<?php
namespace Ep\Cache\Adapter;

use Interop\Container\ContainerInterface;
use Symfony\Component\Cache\Adapter\FilesystemAdapter;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu Filesystem ili PhpFiles cache adaptera.
 *
 * @package Ep\Cache\Adapter
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-framework
 */
class FilesystemFactory implements FactoryInterface
{
    /**
     * Stvara adapter.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return FilesystemAdapter
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $options = $options ?? [];

        $namespace = $options['namespace'] ?? '';
        $defaultLifetime = intval($options['default_lifetime'] ?? 0);
        $directory = $options['directory'] ?? (defined('CACHE_DIR') ? CACHE_DIR : 'var/cache');

        if (!empty($directory) && !is_dir($directory)) {
            mkdir($directory, 0777, true);
        }

        return new $requestedName($namespace, $defaultLifetime, $directory);
    }
}