<?php
namespace Ep\Cache\Adapter;

use Ep\Cache\Exception\OptionRequiredException;
use Interop\Container\ContainerInterface;
use Symfony\Component\Cache\Adapter\PhpArrayAdapter;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu PhpArray cache adaptera.
 *
 * @package Ep\Cache\Adapter
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-framework
 */
class PhpArrayFactory implements FactoryInterface
{
    /**
     * Stvara adapter.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return PhpArrayAdapter
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke( ContainerInterface $container, $requestedName, array $options = null )
    {
        $options = $options ?? [];

        if (!isset($options['file']) || empty($options['file'])) {
            throw new OptionRequiredException("Polje 'file' je obavezno.");
        }

        $fallback = isset($options['fallback']) && !empty($options['fallback'])
            ? $container->get($options['fallback'])
            : null;

        return new PhpArrayAdapter($options['file'], $fallback);
    }
}