<?php
namespace Ep\Db\Adapter;

use Ep\Db\Adapter\Platform\SqlServer;
use Interop\Container\ContainerInterface;
use Zend\Db\Adapter\Adapter;
use Zend\Db\Adapter\AdapterInterface;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu Db adaptera.
 *
 * @package Ep\Db\Adapter
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-framework
 */
class AdapterServiceFactory implements FactoryInterface
{
    /**
     * Stvara adapter.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return AdapterInterface
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['db'] ?? [];

        if (isset($config['driver']) && preg_match('#sqlsrv#', strtolower($config['driver']))) {
            return new Adapter($config, new SqlServer());
        }

        return new Adapter($config);
    }
}