<?php
namespace Ep\Mail\Transport;

use Interop\Container\ContainerInterface;
use Zend\Mail\Protocol\SmtpPluginManager;
use Zend\Mail\Transport\Factory;
use Zend\Mail\Transport\Smtp;
use Zend\Mail\Transport\TransportInterface;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Class TransportFactory
 *
 * @package Ep\Mail\Transport
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-framework
 */
class AbstractTransportFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return TransportInterface
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['mail'] ?? [];

        $transport = Factory::create($config);

        if ($transport instanceof Smtp) {
            $plugins = $container->get(SmtpPluginManager::class);
            $transport->setPluginManager($plugins);
        }

        return $transport;
    }
}