<?php
namespace Ep\Middleware;

use Ep\Currency\Adapter\AdapterInterface;
use Interop\Http\Server\MiddlewareInterface;
use Interop\Http\Server\RequestHandlerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Zend\Diactoros\Response\JsonResponse;
use Zend\Diactoros\Response\TextResponse;

/**
 * Poslužuje tečajnu listu.
 *
 * @package Ep\Middleware
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-currency
 */
class ExchangeRates implements MiddlewareInterface
{
    /** @var AdapterInterface */
    private $adapter;

    /**
     * ExchangeRates constructor.
     *
     * @param AdapterInterface $adapter
     */
    public function __construct(AdapterInterface $adapter)
    {
        $this->adapter = $adapter;
    }

    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler)
    {
        $query = $request->getQueryParams();
        $baseCurrency = $query['base'] ?? AdapterInterface::BASE_CURRENCY;
        $rates = $this->adapter->getRates($baseCurrency);

        if (preg_match('/(Mozilla|Chrome)/', $request->getHeaderLine('User-Agent'))) {
            return new TextResponse(print_r($rates, true));
        }

        return new JsonResponse($rates);
    }
}