<?php
namespace EpTest\Http;

use Ep\Cache\AbstractCacheFactory;
use Ep\Http\AbstractHttpClientFactory;
use Ep\Http\Middleware\Cache;
use GuzzleHttp\Client;
use GuzzleHttp\ClientInterface;
use PHPUnit\Framework\TestCase;
use Psr\Container\ContainerInterface;
use Zend\ServiceManager\ServiceManager;

/**
 * Class AbstractHttpClientFactoryTest
 *
 * @package EpTest\Http
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-framework
 */
class AbstractHttpClientFactoryTest extends TestCase
{
    /** @var ContainerInterface */
    private $container;

    protected function setUp()
    {
        parent::setUp();

        $this->container = new ServiceManager([
            'abstract_factories' => [
                AbstractCacheFactory::class,
                AbstractHttpClientFactory::class,
            ],
        ]);

        $this->container->setService('config', [
            'http_clients' => [
                'http.general' => [],

                'http.bin' => [
                    'base_uri' => 'http://httpbin.org',
                ],

                'http.cached' => [
                    'base_uri' => 'http://httpbin.org',
                    'cache' => 'cache.http',
                ],
            ],

            'caches' => [
                'cache.http' => [
                    'adapter' => 'array',
                    'options' => [
                        'default_lifetime' => 1,
                    ],
                ],
            ],
        ]);
    }

    /**
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function testCanCreateClients()
    {
        $this->assertTrue($this->container->has('http.general'));

        $client = $this->container->get('http.general');

        $this->assertInstanceOf(ClientInterface::class, $client);
        $this->assertSame($client, $this->container->get('http.general'));
    }

    /**
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function testCanCreateConfiguredClients()
    {
        /** @var Client $client */
        $client = $this->container->get('http.bin');

        $response = $client->get('/get');
        $this->assertEquals('application/json', $response->getHeaderLine('Content-Type'));
    }

    /**
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function testCanCreateCacheableClients()
    {
        /** @var Client $client */
        $client = $this->container->get('http.cached');

        $response = $client->get('/get');

        $this->assertTrue($response->hasHeader(Cache::HEADER_CACHE_INFO));
    }
}