<?php
namespace EpTest\Middleware;

use Ep\Middleware\BaseUrl;
use PHPUnit\Framework\TestCase;
use Psr\Http\Message\ServerRequestInterface;
use Zend\Diactoros\Response;
use Zend\Diactoros\ServerRequestFactory;
use Zend\Stratigility\Delegate\CallableDelegateDecorator;

/**
 * Class BaseUrlTest
 *
 * @package EpTest\Middleware
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-framework
 */
class BaseUrlTest extends TestCase
{
    public function testCanDetectBaseUrlAndPath()
    {
        $request = ServerRequestFactory::fromGlobals([
            'SCRIPT_FILENAME' => '/home/user/directory/index.php',
            'SCRIPT_NAME' => '/directory/index.php',
            'PHP_SELF' => '/directory/index.php',
            'REQUEST_URI' => '/directory/',
        ]);

        $middleware = new BaseUrl();

        /** @noinspection PhpParamsInspection */
        $middleware->process($request, new CallableDelegateDecorator(function(ServerRequestInterface $request) {
            $this->assertEquals('/directory', $request->getAttribute(BaseUrl::BASE_URL));
            $this->assertEquals('/directory', $request->getAttribute(BaseUrl::BASE_PATH));
        }, new Response()));
    }

    public function testCanDetectBaseUrlWithScriptNameInRequestUri()
    {
        $request = ServerRequestFactory::fromGlobals([
            'SCRIPT_FILENAME' => '/home/user/webshop/wp/wp-admin/install.php',
            'SCRIPT_NAME' => '/webshop/wp/wp-admin/install.php',
            'PHP_SELF' => '/webshop/wp/wp-admin/install.php',
            'REQUEST_URI' => '/webshop/wp/wp-admin/install.php',
        ]);

        $middleware = new BaseUrl();

        /** @noinspection PhpParamsInspection */
        $middleware->process($request, new CallableDelegateDecorator(function(ServerRequestInterface $request) {
            $this->assertEquals('/webshop/wp/wp-admin', $request->getAttribute(BaseUrl::BASE_URL));
            $this->assertEquals('/webshop/wp/wp-admin', $request->getAttribute(BaseUrl::BASE_PATH));
        }, new Response()));
    }
}